<?php

/*
 * This file is part of the Tajine software.
 * <https://gitlab.adullact.net/adullact/pki/tajine>
 *
 * Copyright (c) ADULLACT   <https://adullact.org>
 *               Association des Développeurs et Utilisateurs de Logiciels Libres
 *               pour les Administrations et les Collectivités Territoriales
 *
 * Tajine is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this software. If not, see <https://www.gnu.org/licenses/agpl-3.0.en.html>.
 */

declare(strict_types=1);

namespace App\DataFixtures;

use App\DataFixtures\AppCertificateAuthorityFixtures;
use App\DataFixtures\AppUserFixtures;
use App\Entity\Certificate;
use Doctrine\Bundle\FixturesBundle\Fixture;
use Doctrine\Common\DataFixtures\DependentFixtureInterface;
use Doctrine\Persistence\ObjectManager;

class AppCertificateFixtures extends Fixture implements DependentFixtureInterface
{
    public function getDependencies()
    {
        return [
            AppCertificateAuthorityFixtures::class,
            AppUserFixtures::class,
        ];
    }

    public function load(ObjectManager $manager): void
    {
        /////////////////////////////////////////////////////////////////////////////////
        $cert1 = new Certificate();
        $cert1->setSerialNumber('0x468B91C7D3F967FBD62F969A251CF740E1F066DA');
        $cert1->setValidFrom(new \DateTimeImmutable('2023-06-19 16:11:00 +00:00'));
        $cert1->setValidTo(new \DateTimeImmutable('2024-06-18 16:11:00 +00:00'));
        $cert1->setSubject(
            '/C=FR' .
            '/ST=PYRENEES-ATLANTIQUES' .
            '/L=CAUDIES-DE-CONFLENT' .
            '/O=MAIRIE-DE-CAUDIES-DE-CONFLENT' .
            '/OU=SERVICE-DES-SPORS-DE-LA-VILLE-DE-CAUDIES-DE-CONFLENT' .
            '/CN=TEST_USER_1_TAJINE@EXAMPLE.ORG'
        );
        $cert1->setCreatedBy($this->getReference(AppUserFixtures::USER_REFERENCE_MANAGER_2));
        $cert1->setUsedBy($this->getReference(AppUserFixtures::USER_REFERENCE_1));
        $cert1->setRevoked(false);
        $cert1->setExpired(false);
        $cert1->setAuthority($this->getReference(AppCertificateAuthorityFixtures::CERT_AUTHORITY_1));
        $cert1->setPublicKey('-----BEGIN CERTIFICATE-----
MIIEqDCCA5CgAwIBAgIURouRx9P5Z/vWL5aaJRz3QOHwZtowDQYJKoZIhvcNAQEL
BQAweTELMAkGA1UEBhMCRlIxFDASBgNVBAcTC01PTlRQRUxMSUVSMSUwIwYDVQQK
ExxWQUdSQU5UIEVYQU1QTEUgT1JHQU5JWkFUSU9OMS0wKwYDVQQDEyRWQUdSQU5U
IEVYQU1QTEUgSU5URVJNRURJQVRFIENBIEdFTjEwHhcNMjMwNjE5MTYxMTAwWhcN
MjQwNjE4MTYxMTAwWjCB2jELMAkGA1UEBhMCRlIxHTAbBgNVBAgTFFBZUkVORUVT
LUFUTEFOVElRVUVTMRwwGgYDVQQHExNDQVVESUVTLURFLUNPTkZMRU5UMSYwJAYD
VQQKEx1NQUlSSUUtREUtQ0FVRElFUy1ERS1DT05GTEVOVDE9MDsGA1UECxM0U0VS
VklDRS1ERVMtU1BPUlMtREUtTEEtVklMTEUtREUtQ0FVRElFUy1ERS1DT05GTEVO
VDEnMCUGA1UEAwweVEVTVF9VU0VSXzFfVEFKSU5FQEVYQU1QTEUuT1JHMIIBIjAN
BgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAqNp6FK6KZbSPNjhvis9+bA3z73aH
MiISjB+aC3m3DEQo4C429Tg8s5YdKbdmY2TYYhS6S/H8tlrzQN5Tnwr98FhG+ZFh
wLkhYu9fBH668NhQGJCxucwDDCr5O84lNVonHAO6tG2govS7seBoCqU/F+T8yggN
Bk0QmGthMwabDYLUHBEflBq6hbLFZF2z4Yr3EWa/GEriZPKfH5PDlOOGJN6/a/UQ
gKNyl0ZUPyAxDDdsw0XobZNrHSjhSu53ItDrlbHwAAz4ORs8kkJ13Ya1X0ukDzcw
n+YVTkzEITQMunOtoQTvY/fnSky+WAosuri+/2AcaVNc2NejFF+P+bZLaQIDAQAB
o4HFMIHCMBMGA1UdJQQMMAoGCCsGAQUFBwMCMAwGA1UdEwEB/wQCMAAwHQYDVR0O
BBYEFN5bWACRzSNTtWtXLgq4jWNUrkyUMB8GA1UdIwQYMBaAFHErrb3INhdd387l
t+oHFBVkUjv4MAsGA1UdEQQEMAKCADBQBgNVHR8ESTBHMEWgQ6BBhj9odHRwOi8v
Y3JsLmV4YW1wbGUub3JnL2NybC1WQUdSQU5URVhBTVBMRUlOVEVSTUVESUFURUNB
R0VOMS5jcmwwDQYJKoZIhvcNAQELBQADggEBAJurjjB99x81yVq1jMhLuK1KV9qH
8KslQFBSGSYo6ACeiSqeNhK3hgQKt5jD4GHVHgctZ6TlShVkvQvnLdL6msFHqgb2
MDmJOh0LKTb9Sv4Cyvuibpey0EIVqA/LNl4PR7/dwlrpnEawuG4ywbZV4TCIKcuD
6WlVdPfDSr4+j9+4Zk99UtaIFfhCEnFCZyv8cbQ4dKeL4wbzWE/kNV9QRm8o1Z2D
udHDhXunee/i3hxzrnvCzsTe+J8xAHgKNCwMnwDNcl0HE+KWmg522tsGBxI+OYSc
F4JfLMqxlpcp7p/8AZNHZeevRAO23l8p/N7QMj1bTp+AOBFsSaKLoR24Q1s=
-----END CERTIFICATE-----
');
        $manager->persist($cert1);
        /////////////////////////////////////////////////////////////////////////////////
        $cert2 = new Certificate();
        $cert2->setSerialNumber('0x58F3C5938D6B1863BC56525264FBDD2209C60BCF');
        $cert2->setValidFrom(new \DateTimeImmutable('2023-06-19 17:19:00 +00:00'));
        $cert2->setValidTo(new \DateTimeImmutable('2024-06-18 17:19:00 +00:00'));
        $cert2->setSubject(
            '/C=FR' .
            '/ST=HERAULT' .
            '/L=SAINT-ANDRE-DE-BUEGES' .
            '/O=MAIRIE-DE-SAINT-ANDRE-DE-BUEGES' .
            '/OU=SERVICE-TECHNIQUE-DE-LA-VILLE-DE-SAINT-ANDRE-DE-BUEGES' .
            '/CN=TEST_USER_2_TAJINE@EXAMPLE.ORG'
        );
        $cert2->setCreatedBy($this->getReference(AppUserFixtures::USER_REFERENCE_MANAGER_2));
        $cert2->setUsedBy($this->getReference(AppUserFixtures::USER_REFERENCE_2));
        $cert2->setRevoked(false);
        $cert2->setExpired(false);
        $cert2->setAuthority($this->getReference(AppCertificateAuthorityFixtures::CERT_AUTHORITY_1));
        $cert2->setPublicKey('-----BEGIN CERTIFICATE-----
MIIEoTCCA4mgAwIBAgIUWPPFk41rGGO8VlJSZPvdIgnGC88wDQYJKoZIhvcNAQEL
BQAweTELMAkGA1UEBhMCRlIxFDASBgNVBAcTC01PTlRQRUxMSUVSMSUwIwYDVQQK
ExxWQUdSQU5UIEVYQU1QTEUgT1JHQU5JWkFUSU9OMS0wKwYDVQQDEyRWQUdSQU5U
IEVYQU1QTEUgSU5URVJNRURJQVRFIENBIEdFTjEwHhcNMjMwNjE5MTcxOTAwWhcN
MjQwNjE4MTcxOTAwWjCB0zELMAkGA1UEBhMCRlIxEDAOBgNVBAgTB0hFUkFVTFQx
HjAcBgNVBAcTFVNBSU5ULUFORFJFLURFLUJVRUdFUzEoMCYGA1UEChMfTUFJUklF
LURFLVNBSU5ULUFORFJFLURFLUJVRUdFUzE/MD0GA1UECxM2U0VSVklDRS1URUNI
TklRVUUtREUtTEEtVklMTEUtREUtU0FJTlQtQU5EUkUtREUtQlVFR0VTMScwJQYD
VQQDDB5URVNUX1VTRVJfMl9UQUpJTkVARVhBTVBMRS5PUkcwggEiMA0GCSqGSIb3
DQEBAQUAA4IBDwAwggEKAoIBAQDXpc6fgIm2fXhJHWlx8PIoUoOpVAhqCXVlyAzd
ZpUTjP+95T05qLH/8ZkEP6NF+qO0C9uvT2mOw3Lbych7DYwHMFU18kXUiQeOrL3y
qLlHm2EYKxwA7YbTZbKrPe40D0GPEjgl74qIZFK/vgnMA47j2d98XkU593Sssrf6
cOtIf/lfDMF9xDYPs+FCP77VV3j2e+2MpAYKL26oqn3HRsr3P4pBg2VnMl2IAeaM
aBkS8lreHrBspfx3Svzc3GC/gg1moD+352uMEO/AjIn+LZqdjYQhNQWODDpfyb31
EOG4CTnfXrZdtPaaV5B7shFwUNUQR9qQNxxss0RhtIlMXwdnAgMBAAGjgcUwgcIw
EwYDVR0lBAwwCgYIKwYBBQUHAwIwDAYDVR0TAQH/BAIwADAdBgNVHQ4EFgQUrepq
HsK5Ao2OH1sXTad6vWeCfVkwHwYDVR0jBBgwFoAUcSutvcg2F13fzuW36gcUFWRS
O/gwCwYDVR0RBAQwAoIAMFAGA1UdHwRJMEcwRaBDoEGGP2h0dHA6Ly9jcmwuZXhh
bXBsZS5vcmcvY3JsLVZBR1JBTlRFWEFNUExFSU5URVJNRURJQVRFQ0FHRU4xLmNy
bDANBgkqhkiG9w0BAQsFAAOCAQEAQOxAriNWsgixJHxNS1YuL60xEJjpnGwILYJb
qtGbb9iD4qD481Pqm1LkiIJbpTF4xaZ07ejMpg8fAc43WifET0KPHCPlx5BM4PXF
O4kKgKbUslFOLMYQkPzTmqdhpCidRgFqzABqTPqOQ4FYLbUuKsL4IH7RvWWiBfg5
N/3xTL7vx5asRjLOlUt/tkWYMK+y2qleiy604/hi5v6/DNdPmbpnqjltmo/ib6cL
Z+KTAnftjHxPtZUSDiiDYIBFSD2EmQNsc341RAcQOw8OdHgAnQxV772AkGN///B8
zNH/Cf3Y7H7VAq+SBYIa6UwXNRi306w2SY9Khi6j5N6GYFxXBg==
-----END CERTIFICATE-----
');
        $manager->persist($cert2);
        /////////////////////////////////////////////////////////////////////////////////
        $cert3 = new Certificate();
        $cert3->setSerialNumber('0x33BDE2E6F0138FA1E24B629B0E3C5D44F4E4386C');
        $cert3->setValidFrom(new \DateTimeImmutable('2023-06-19 17:31:00 +00:00'));
        $cert3->setValidTo(new \DateTimeImmutable('2024-06-18 17:31:00 +00:00'));
        $cert3->setSubject(
            '/C=FR' .
            '/ST=PUY-DE-DOME' .
            '/L=CLERMONT-FERRAND' .
            '/O=CLERMONT-AUVERGNE-METROPOLE' .
            '/OU=SERVICE-INFORMATIQUE-DE-CLERMONT-AUVERGNE-METROPOLE' .
            '/CN=TEST_USER_3_TAJINE@EXAMPLE.ORG'
        );
        $cert3->setCreatedBy($this->getReference(AppUserFixtures::USER_REFERENCE_MANAGER_1));
        $cert3->setUsedBy($this->getReference(AppUserFixtures::USER_REFERENCE_3));
        $cert3->setRevoked(false);
        $cert3->setExpired(false);
        $cert3->setAuthority($this->getReference(AppCertificateAuthorityFixtures::CERT_AUTHORITY_1));
        $cert3->setPublicKey('-----BEGIN CERTIFICATE-----
MIIEmTCCA4GgAwIBAgIUM73i5vATj6HiS2KbDjxdRPTkOGwwDQYJKoZIhvcNAQEL
BQAweTELMAkGA1UEBhMCRlIxFDASBgNVBAcTC01PTlRQRUxMSUVSMSUwIwYDVQQK
ExxWQUdSQU5UIEVYQU1QTEUgT1JHQU5JWkFUSU9OMS0wKwYDVQQDEyRWQUdSQU5U
IEVYQU1QTEUgSU5URVJNRURJQVRFIENBIEdFTjEwHhcNMjMwNjE5MTczMTAwWhcN
MjQwNjE4MTczMTAwWjCByzELMAkGA1UEBhMCRlIxFDASBgNVBAgTC1BVWS1ERS1E
T01FMRkwFwYDVQQHExBDTEVSTU9OVC1GRVJSQU5EMSQwIgYDVQQKExtDTEVSTU9O
VC1BVVZFUkdORS1NRVRST1BPTEUxPDA6BgNVBAsTM1NFUlZJQ0UtSU5GT1JNQVRJ
UVVFLURFLUNMRVJNT05ULUFVVkVSR05FLU1FVFJPUE9MRTEnMCUGA1UEAwweVEVT
VF9VU0VSXzNfVEFKSU5FQEVYQU1QTEUuT1JHMIIBIjANBgkqhkiG9w0BAQEFAAOC
AQ8AMIIBCgKCAQEAnAdaL6H4h/HD0AjUQykZN1D6QsuiHo5cUnjQvJdPzqo8UgSC
CPgJtLQF23kANoEDpmhZrH57034thffPA0VKnvchkYZ1Zi6af1KH3ApbYprIUVKd
wbeKXni26ntku6gZP07VAd0tOHMdMRXaJCWR7W2Tclm5V0JNmSRj0HxmjlDh0Gtu
Bf1yFLuNt0iVibBOaMk3YNkhX9qle/tWVn8x/QKQ7xEV3BHzAl4jzyjyCaBK0MKF
MCEYpCJIZz5Voic+LghvgNfT0Me7bf/Aub1SBB9bV1e5F79RgRe/o3fRzYd1ShJ9
+U/jhIPeUw3SzehNps0g2U/bcpQw90vzh0asAwIDAQABo4HFMIHCMBMGA1UdJQQM
MAoGCCsGAQUFBwMCMAwGA1UdEwEB/wQCMAAwHQYDVR0OBBYEFBnXSR3m++XPdJ4M
JCldfwbeoMVjMB8GA1UdIwQYMBaAFHErrb3INhdd387lt+oHFBVkUjv4MAsGA1Ud
EQQEMAKCADBQBgNVHR8ESTBHMEWgQ6BBhj9odHRwOi8vY3JsLmV4YW1wbGUub3Jn
L2NybC1WQUdSQU5URVhBTVBMRUlOVEVSTUVESUFURUNBR0VOMS5jcmwwDQYJKoZI
hvcNAQELBQADggEBADup++TeJBn1fy5slaAYvdvhn5xKRNxR587duk7+0asb1KSt
uPbdhbzHShlfzFXp8r+MIZt/HUEnQ2NUe/GMAji+Gaiam5VYuBx5sOwE0jwLzwvO
iIujhq5cEsDVR4ssLhtXOsAVG2CRFzQX2Wd0IHabWibjvWS5NNiFlMRQUUC2RRs3
Waws86exSMWldBXO0FGiB52bBPprqjD1kUWZwyNVnXElg4IW2hhj4yIVjtgnj/Ir
h1aDclyRXIhTlqoFZsqkGUuL68TtB3iFUEfYm0ovrnHj8RYa0s+p7/v1RONJvch2
iq92oxH5GspcL9UqT7YH4Bu++Cn1MN7U4srbGas=
-----END CERTIFICATE-----
');
        $manager->persist($cert3);
        /////////////////////////////////////////////////////////////////////////////////
//        $cert3 = new Certificate();
//        $cert3->setSerialNumber('');
//        $cert3->setValidFrom(new \DateTimeImmutable(''));
//        $cert3->setValidTo(new \DateTimeImmutable(''));
//        $cert3->setSubject('');
//        $cert3->setCreatedBy($this->getReference(AppUserFixtures::USER_REFERENCE_MANAGER_2));
//        $cert3->setUsedBy($this->getReference(AppUserFixtures::USER_REFERENCE_3));
//        $cert3->setRevoked(false);
//        $cert3->setExpired(false);
//        $cert3->setAuthority($this->getReference(AppCertificateAuthorityFixtures::CERT_AUTHORITY_1));
//        $cert3->setPublicKey('');
//        $manager->persist($cert3);
        /////////////////////////////////////////////////////////////////////////////////
        $manager->flush();
    }
}
